pub enum CompileFileOutcome {
Compiled(CompileArtifacts),
SkippedNoEntrypoint,
}Expand description
Result of one callback-driven compile request.
Variants
Compiled(CompileArtifacts)
The script compiled successfully and artifacts were written through the host.
SkippedNoEntrypoint
The script was skipped because it has no executable entrypoint.