Keyword

Enum Keyword 

pub enum Keyword {
Show 38 variants If, Do, Else, Int, Float, String, Object, Return, While, For, Void, Case, Break, Struct, Action, Switch, Default, Include, Continue, Vector, Const, Define, ObjectSelf, ObjectInvalid, EngineNumStructuresDefinition, EngineStructureDefinition, JsonNull, JsonFalse, JsonTrue, JsonObject, JsonArray, JsonString, LocationInvalid, FunctionMacro, FileMacro, LineMacro, DateMacro, TimeMacro,
}
One NWScript keyword or builtin token recognized during lexing.

Variants



If

if



Do

do



Else

else



Int

int



Float

float



String

string



Object

object



Return

return



While

while



For

for



Void

void



Case

case



Break

break



Struct

struct



Action

action



Switch

switch



Default

default



Include

#include



Continue

continue



Vector

vector



Const

const



Define

#define



ObjectSelf

OBJECT_SELF



ObjectInvalid

OBJECT_INVALID



EngineNumStructuresDefinition

ENGINE_NUM_STRUCTURES



EngineStructureDefinition

ENGINE_STRUCTURE_0 through ENGINE_STRUCTURE_9



JsonNull

JSON_NULL



JsonFalse

JSON_FALSE



JsonTrue

JSON_TRUE



JsonObject

JSON_OBJECT



JsonArray

JSON_ARRAY



JsonString

JSON_STRING



LocationInvalid

LOCATION_INVALID



FunctionMacro

__FUNCTION__



FileMacro

__FILE__



LineMacro

__LINE__



DateMacro

__DATE__



TimeMacro

__TIME__

Implementations

Source

impl Keyword

pub const fn as_str(self) -> &'static str

Returns the canonical source text for this keyword.

pub const fn upstream_token_code(self) -> u16

Returns the upstream token code from scriptinternal.h.

pub fn from_lexeme(input: &str) -> Option<Self>

Resolves a keyword from its exact source spelling.