NcsOpcode

Enum NcsOpcode 

#[repr(u8)]
pub enum NcsOpcode {
Show 45 variants Assignment = 1, RunstackAdd = 2, RunstackCopy = 3, Constant = 4, ExecuteCommand = 5, LogicalAnd = 6, LogicalOr = 7, InclusiveOr = 8, ExclusiveOr = 9, BooleanAnd = 10, Equal = 11, NotEqual = 12, Geq = 13, Gt = 14, Lt = 15, Leq = 16, ShiftLeft = 17, ShiftRight = 18, UShiftRight = 19, Add = 20, Sub = 21, Mul = 22, Div = 23, Modulus = 24, Negation = 25, OnesComplement = 26, ModifyStackPointer = 27, StoreIp = 28, Jmp = 29, Jsr = 30, Jz = 31, Ret = 32, DeStruct = 33, BooleanNot = 34, Decrement = 35, Increment = 36, Jnz = 37, AssignmentBase = 38, RunstackCopyBase = 39, DecrementBase = 40, IncrementBase = 41, SaveBasePointer = 42, RestoreBasePointer = 43, StoreState = 44, NoOperation = 45,
}
One NWScript VM opcode.

Variants



Assignment = 1

CPDOWNSP



RunstackAdd = 2

RSADD



RunstackCopy = 3

CPTOPSP



Constant = 4

CONST



ExecuteCommand = 5

ACTION



LogicalAnd = 6

LOGAND



LogicalOr = 7

LOGOR



InclusiveOr = 8

INCOR



ExclusiveOr = 9

EXCOR



BooleanAnd = 10

BOOLAND



Equal = 11

EQUAL



NotEqual = 12

NEQUAL



Geq = 13

GEQ



Gt = 14

GT



Lt = 15

LT



Leq = 16

LEQ



ShiftLeft = 17

SHLEFT



ShiftRight = 18

SHRIGHT



UShiftRight = 19

USHRIGHT



Add = 20

ADD



Sub = 21

SUB



Mul = 22

MUL



Div = 23

DIV



Modulus = 24

MOD



Negation = 25

NEG



OnesComplement = 26

COMP



ModifyStackPointer = 27

MOVSP



StoreIp = 28

STOREIP



Jmp = 29

JMP



Jsr = 30

JSR



Jz = 31

JZ



Ret = 32

RET



DeStruct = 33

DESTRUCT



BooleanNot = 34

NOT



Decrement = 35

DECSP



Increment = 36

INCSP



Jnz = 37

JNZ



AssignmentBase = 38

CPDOWNBP



RunstackCopyBase = 39

CPTOPBP



DecrementBase = 40

DECBP



IncrementBase = 41

INCBP



SaveBasePointer = 42

SAVEBP



RestoreBasePointer = 43

RESTOREBP



StoreState = 44

STORESTATE



NoOperation = 45

NOP

Implementations

Source

impl NcsOpcode

pub fn canonical_name(self) -> &'static str

Returns the canonical mnemonic used by the upstream assembler helper.

Source

impl NcsOpcode

pub fn internal_name(self) -> &'static str

Returns the upstream internal opcode constant name used by nwasm.