pub enum SourceError {
Resolver(String),
Compiler {
code: CompilerErrorCode,
script_name: String,
message: String,
},
}Expand description
Errors returned while resolving or loading source files.
Variants
Resolver(String)
The source resolver itself failed.
Compiler
The requested source file could not be loaded or violated a compiler rule.
Implementations
Sourceimpl SourceError
impl SourceError
Sourcepub fn code(&self) -> Option<CompilerErrorCode>
pub fn code(&self) -> Option<CompilerErrorCode>
Returns the upstream compiler error code when this is a compiler failure.
Sourcepub fn file_not_found(script_name: impl Into<String>) -> Self
pub fn file_not_found(script_name: impl Into<String>) -> Self
Creates a file-not-found error.
Sourcepub fn include_recursive(script_name: impl Into<String>) -> Self
pub fn include_recursive(script_name: impl Into<String>) -> Self
Creates an include-recursive error.
Sourcepub fn include_too_many_levels(
script_name: impl Into<String>,
max_include_depth: usize,
) -> Self
pub fn include_too_many_levels( script_name: impl Into<String>, max_include_depth: usize, ) -> Self
Creates an include-too-many-levels error.