load_source_bundle

Function load_source_bundle 

pub fn load_source_bundle<R: ScriptResolver + ?Sized>(
    resolver: &R,
    root_name: &str,
    options: SourceLoadOptions,
) -> Result<SourceBundle, PreprocessError>
Loads a root script and recursively discovers its #include dependencies.

Errors

Returns PreprocessError if any script cannot be resolved or loaded.