pub struct CompilerSessionOptions {
pub langspec_script_name: String,
pub source_load: SourceLoadOptions,
pub compile: CompileOptions,
pub emit_debug: bool,
}Expand description
Configuration for one reusable NWScript compiler session.
Fields
langspec_script_name: StringLogical script name used to load the builtin language specification.
source_load: SourceLoadOptionsSource loading configuration used for the langspec and all compilations.
compile: CompileOptionsCode generation options applied to each compile request.
emit_debug: boolWhether compilations should emit NDB debugger output when available.