pub struct NcsInstruction {
pub opcode: NcsOpcode,
pub auxcode: NcsAuxCode,
pub extra: Vec<u8>,
}Expand description
One decoded NCS instruction.
Fields
opcode: NcsOpcodeOperation code.
auxcode: NcsAuxCodeAuxiliary code.
extra: Vec<u8>Encoded instruction payload after opcode and auxcode.
Implementations
Sourceimpl NcsInstruction
impl NcsInstruction
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the full encoded byte length of this instruction.
Sourceimpl NcsInstruction
impl NcsInstruction
Sourcepub fn canonical_name(&self, internal: bool) -> String
pub fn canonical_name(&self, internal: bool) -> String
Returns the upstream nwasm instruction name.
Sourcepub fn extra_string(
&self,
max_string_length: usize,
) -> Result<String, NcsAsmError>
pub fn extra_string( &self, max_string_length: usize, ) -> Result<String, NcsAsmError>
Renders the decoded operand payload using upstream nwasm formatting
rules.
Errors
Returns NcsAsmError if formatting the operand fails.