pub struct PreprocessedSource {
pub tokens: Vec<Token>,
pub defines: Vec<MacroDefinition>,
}Expand description
One preprocessed token stream plus the macros captured while producing it.
Fields
tokens: Vec<Token>Tokens after include traversal and object-like macro expansion.
defines: Vec<MacroDefinition>Macro definitions in encounter order, with later redefinitions included.