pub struct SourceMap { /* private fields */ }Expand description
A collection of loaded source files indexed by both id and normalized name.
Implementations
Sourceimpl SourceMap
impl SourceMap
Sourcepub fn next_id(&self) -> SourceId
pub fn next_id(&self) -> SourceId
Returns the next identifier that would be assigned to a new file.
Sourcepub fn insert_file(&mut self, file: SourceFile) -> SourceId
pub fn insert_file(&mut self, file: SourceFile) -> SourceId
Inserts a fully constructed source file.
Sourcepub fn add_file(
&mut self,
name: impl Into<String>,
contents: impl Into<Vec<u8>>,
) -> SourceId
pub fn add_file( &mut self, name: impl Into<String>, contents: impl Into<Vec<u8>>, ) -> SourceId
Creates and inserts a new source file.
Sourcepub fn get(&self, id: SourceId) -> Option<&SourceFile>
pub fn get(&self, id: SourceId) -> Option<&SourceFile>
Returns the file for id.
Sourcepub fn get_by_name(&self, name: &str) -> Option<&SourceFile>
pub fn get_by_name(&self, name: &str) -> Option<&SourceFile>
Returns the file for name, using case-insensitive matching.
Sourcepub fn contains_name(&self, name: &str) -> bool
pub fn contains_name(&self, name: &str) -> bool
Returns true when a file with name has already been loaded.
Sourcepub fn iter(&self) -> impl Iterator<Item = &SourceFile>
pub fn iter(&self) -> impl Iterator<Item = &SourceFile>
Iterates over loaded source files in insertion order.