pub struct VmRunOptions {
pub max_instructions: Option<usize>,
}Expand description
One set of optional execution controls for a VM run.
Fields
max_instructions: Option<usize>Maximum number of instructions that may execute before the VM aborts with an error.