#[repr(u8)]pub enum NcsAuxCode {
Show 39 variants
None = 0,
TypeVoid = 1,
TypeCommand = 2,
TypeInteger = 3,
TypeFloat = 4,
TypeString = 5,
TypeObject = 6,
TypeEngst0 = 16,
TypeEngst1 = 17,
TypeEngst2 = 18,
TypeEngst3 = 19,
TypeEngst4 = 20,
TypeEngst5 = 21,
TypeEngst6 = 22,
TypeEngst7 = 23,
TypeEngst8 = 24,
TypeEngst9 = 25,
TypeTypeIntegerInteger = 32,
TypeTypeFloatFloat = 33,
TypeTypeObjectObject = 34,
TypeTypeStringString = 35,
TypeTypeStructStruct = 36,
TypeTypeIntegerFloat = 37,
TypeTypeFloatInteger = 38,
TypeTypeEngst0Engst0 = 48,
TypeTypeEngst1Engst1 = 49,
TypeTypeEngst2Engst2 = 50,
TypeTypeEngst3Engst3 = 51,
TypeTypeEngst4Engst4 = 52,
TypeTypeEngst5Engst5 = 53,
TypeTypeEngst6Engst6 = 54,
TypeTypeEngst7Engst7 = 55,
TypeTypeEngst8Engst8 = 56,
TypeTypeEngst9Engst9 = 57,
TypeTypeVectorVector = 58,
TypeTypeVectorFloat = 59,
TypeTypeFloatVector = 60,
EvalInplace = 112,
EvalPostplace = 113,
}Expand description
One NWScript VM aux code.
Variants
None = 0
No auxcode.
TypeVoid = 1
void.
TypeCommand = 2
command type.
TypeInteger = 3
integer type.
TypeFloat = 4
float type.
TypeString = 5
string type.
TypeObject = 6
object type.
TypeEngst0 = 16
engine structure 0.
TypeEngst1 = 17
engine structure 1.
TypeEngst2 = 18
engine structure 2.
TypeEngst3 = 19
engine structure 3.
TypeEngst4 = 20
engine structure 4.
TypeEngst5 = 21
engine structure 5.
TypeEngst6 = 22
engine structure 6.
TypeEngst7 = 23
engine structure 7.
TypeEngst8 = 24
engine structure 8.
TypeEngst9 = 25
engine structure 9.
TypeTypeIntegerInteger = 32
integer/integer operator specialization.
TypeTypeFloatFloat = 33
float/float operator specialization.
TypeTypeObjectObject = 34
object/object operator specialization.
TypeTypeStringString = 35
string/string operator specialization.
TypeTypeStructStruct = 36
struct/struct operator specialization.
TypeTypeIntegerFloat = 37
integer/float operator specialization.
TypeTypeFloatInteger = 38
float/integer operator specialization.
TypeTypeEngst0Engst0 = 48
engst0/engst0 operator specialization.
TypeTypeEngst1Engst1 = 49
engst1/engst1 operator specialization.
TypeTypeEngst2Engst2 = 50
engst2/engst2 operator specialization.
TypeTypeEngst3Engst3 = 51
engst3/engst3 operator specialization.
TypeTypeEngst4Engst4 = 52
engst4/engst4 operator specialization.
TypeTypeEngst5Engst5 = 53
engst5/engst5 operator specialization.
TypeTypeEngst6Engst6 = 54
engst6/engst6 operator specialization.
TypeTypeEngst7Engst7 = 55
engst7/engst7 operator specialization.
TypeTypeEngst8Engst8 = 56
engst8/engst8 operator specialization.
TypeTypeEngst9Engst9 = 57
engst9/engst9 operator specialization.
TypeTypeVectorVector = 58
vector/vector operator specialization.
TypeTypeVectorFloat = 59
vector/float operator specialization.
TypeTypeFloatVector = 60
float/vector operator specialization.
EvalInplace = 112
in-place evaluation marker.
EvalPostplace = 113
post-place evaluation marker.
Implementations
Sourceimpl NcsAuxCode
impl NcsAuxCode
Sourcepub fn canonical_name(self) -> Option<&'static str>
pub fn canonical_name(self) -> Option<&'static str>
Returns the canonical short suffix used by the upstream assembler helper.
Sourceimpl NcsAuxCode
impl NcsAuxCode
Sourcepub fn internal_name(self) -> &'static str
pub fn internal_name(self) -> &'static str
Returns the upstream internal auxcode constant name used by nwasm.