pub fn load_source_bundle<R: ScriptResolver + ?Sized>(
resolver: &R,
root_name: &str,
options: SourceLoadOptions,
) -> Result<SourceBundle, PreprocessError>Expand description
Loads a root script and recursively discovers its #include dependencies.
Errors
Returns PreprocessError if any script cannot be resolved or loaded.